import requests

class ImobPost:
    
    def __init__(self, url:str):
        self._url = url
    
    def post(self, data) -> tuple[bool, dict | str]:
        
        response = requests.post(self._url, json=data)
        if response.status_code != 200:
            return True, response
        response_json = response.json()
        return response_json["Header"]["Error"], response_json


from .exec import ImobPost
class ImobAuth(ImobPost):
    def __init__(self, url: str, user: str, password: str):
        super().__init__(url)
        self._user = user
        self._password = password
        self.token = None
    
    def login(self, imob_id:str) -> tuple[bool, dict | str]:
        data = {
            'Header':{
            'Action':"LOGIN"
            },
            'Body':{
                'IMOB_ID':imob_id,
                'USER_ID':self._user,
                'USER_PASS':self._password
            },
        }
        error, response = self.post(data=data)
        if error:
            message = None
            try:
                message = response["Body"]["Erros"]
            except:
                message = response
            return error, message
        self.token = response["Header"]["SessionId"]
        return False, "Login feito com sucesso"
    
    def logout(self) -> dict|str:
        data = {
            'Header':{
            'SessionId':self.token,
            'Action':"LOGOUT"
            },
            'Body':{
            },
        }
        response = self.post(data=data)
        return response


from ..exec import ImobPost

class Condominio(ImobPost):
    def __init__(self, url:str, token:str):
        super().__init__(url)
        self.token = token
        
    def CONDOM_CONDOMINIO_CONSULTAR(self, cod_condominio:str)  -> tuple[bool, dict | str]:
        data = {
            "Header":{
                "SessionId":self.token,
                "Action":"CONDOM_CONDOMINIO_CONSULTAR"
            },
            "Body":{
                "CodCondominio":cod_condominio
            }
        }
        error, response = self.post(data=data)
        
        if error:
            message = None
            try:
                message = response["Body"]["Erros"]
            except:
                message = response
            return error, message
        return False, response["Body"]
        
    def CONDOM_CONDOMINIO_PESQUISAR(self, cnpj:str, qtd_linhas:int)  -> tuple[bool, dict | str]:
        data = {
            "Header":{
                "SessionId":self.token,
                "Action":"CONDOM_CONDOMINIO_PESQUISAR"
            },
            "Body":{
                "Texto":cnpj,
                "OrdenarPor":"C",
                "PesquisarPor":"C",
                "IncluiInativos":"N",
                "QtdeLinhas":qtd_linhas,
            }
        }
        error, response = self.post(data=data)
        
        if error:
            message = None
            try:
                message = response["Body"]["Erros"]
            except:
                message = response
            return error, message
        return False, response["Body"]["Condominios"]
        


import boto3, os

class ClientS3:
    def __init__(self):
        self._s3 = None
        pass
    
    def login(self, access_key: str, secret_key: str):
        session = boto3.Session(
            aws_access_key_id=access_key,
            aws_secret_access_key=secret_key
        )
        self._s3 = session.client("s3")
        
    def upload_file(self, bucket: str, filepath:str):
        filename = os.path.basename(filepath)
        with open(filepath, "rb") as f:
            self._s3.upload_fileobj(  
                f,
                Bucket=bucket,
                Key=filename,
                ExtraArgs={"ContentType": "application/pdf"}
            )



from ..exec import ImobPost

class ContaPagar(ImobPost):
    def __init__(self, url:str, token:str):
        super().__init__(url)
        self.token = token
        
    def CTAPAG_LANCAMENTO_ADICIONAR_IMAGEM(self, lancto: int, url_doc: str) -> tuple[bool, dict | str]:
        data = {
            'Header':{
                'SessionId':self.token,
                'Action':"CTAPAG_LANCAMENTO_ADICIONAR_IMAGEM"
            },
            'Body':{
                'NumeroLancto':lancto,
                'UrlImagem':url_doc
            },
        }       
        error, response = self.post(data=data)
        
        if error:
            message = None
            try:
                message = response["Body"]["Erros"]
            except:
                message = response
            return error, message
        return False, response["Body"]["NumeroLancto"]
    
    def CTAPAG_CONDOMINIO_INCLUIR(self, body:dict) -> tuple[bool, dict | str]:
        data = {
            'Header':{
                'SessionId':self.token,
                'Action':"CTAPAG_CONDOMINIO_INCLUIR"
            },
            'Body': body,
        }     
        error, response = self.post(data=data)
        
        if error:
            message = None
            try:
                message = response["Body"]["Erros"]
            except:
                message = response
            return error, message
        return False, response["Body"]["NumeroLancto"]
    
    def CTAPAG_CODBARRAS_CONSULTAR(self, cod_barras: str) -> tuple[bool, dict | str]:
        data = {
            "Header":{
                "SessionId":self.token,
                "Action":"CTAPAG_CODBARRAS_CONSULTAR"
            },
            "Body":{
                "CodigoBarras":cod_barras
            }
        }
        error, response = self.post(data=data)
        
        if error:
            message = None
            try:
                message = response["Body"]["Erros"]
            except:
                message = response
            return error, message
        return False, response["Body"]

    def CTAPAG_LANCAMENTO_EXCLUIR(self, lancto:int, excluir_prvisao:str = "N")  -> tuple[bool, dict | str]:
        data = {
            "Header":{
                "SessionId":self.token,
                "Action":"CTAPAG_LANCAMENTO_EXCLUIR"
            },
            "Body":{
                "NumeroLancto":lancto,
                "ExcluirPrevisao":excluir_prvisao
            }
        }
        error, response = self.post(data=data)
        
        if error:
            message = None
            try:
                message = response["Body"]["Erros"]
            except:
                message = response
            return error, message
        return False, response["Body"]["NumeroLancto"]

    def CTAPAG_LANCAMENTO_PESQUISAR(self, body: dict) -> tuple[bool, dict | str]:
        
        data = {
            "Header":{
                "SessionId":self.token,
                "Action":"CTAPAG_LANCAMENTO_PESQUISAR"
            },
            "Body":body
        }
        error, response = self.post(data=data)
        
        if error:
            message = None
            try:
                message = response["Body"]["Erros"]
            except:
                message = response
            return error, message
        return False, response["Body"]["Lancamentos"]
    

    def CTAPAG_LANCAMENTO_CONSULTAR(self, lancto: str) -> tuple[bool, dict | str]:
        
        data = {
            "Header":{
                "SessionId":self.token,
                "Action":"CTAPAG_LANCAMENTO_CONSULTAR"
            },
            "Body": {
                "NumeroLancto": lancto
            }
        }
        error, response = self.post(data=data)
        
        if error:
            message = None
            try:
                message = response["Body"]["Erros"]
            except:
                message = response
            return error, message
        return False, response["Body"]
    
    def CTAPAG_IMOVEL_INCLUIR(self, body:dict) -> tuple[bool, dict | str]:
            data = {
                'Header':{
                    'SessionId':self.token,
                    'Action':"CTAPAG_IMOVEL_INCLUIR"
                },
                'Body': body,
            }     
            error, response = self.post(data=data)
            
            if error:
                message = None
                try:
                    message = response["Body"]["Erros"]
                except:
                    message = response
                return error, message
            return False, response["Body"]["NumeroLancto"]